==> konoha-0.2.2-rc2.tar.gz: konoha-0.2.2-rc2/konoha/runtime/konoha_ext.c <==
/****************************************************************************
 * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER
 *
 * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
 *           (c) 2008-      Konoha Software Foundation
 * All rights reserved.
 *
 * You may choose one of the following two licenses when you use konoha.
 * See www.konohaware.org/license.html for further information.
 *
 * (1) GNU General Public License 2.0      (with    KONOHA_UNDER_GPL2)
 * (2) Konoha Software Foundation License 1.0
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

/* ************************************************************************ */

#include"commons.h"
#include<time.h>

/* ************************************************************************ */

#ifdef __cplusplus
extern "C" {
#endif

/* ------------------------------------------------------------------------ */
/* [random] */

void init_genrand(unsigned long s);
void init_genrand64(unsigned long long seed);
unsigned long genrand_int31(void);
unsigned long long genrand64_int63(void);
double genrand_real1(void);
double genrand64_real1(void);

/* ------------------------------------------------------------------------ */

void knh_srand(knh_uinteger_t seed)
{
	if(seed == 0) {
		seed = (knh_uinteger_t)time(NULL);
	}
#ifdef KNH_USING_INT32
	init_genrand((unsigned long)seed);
#else
	init_genrand64((unsigned long long int)seed);
#endif
}

/* ------------------------------------------------------------------------ */
/* void System.setRandomSeed(Int seed) */

METHOD knh__System_setRandomSeed(Ctx *ctx, knh_sfp_t *sfp)
{
	knh_uinteger_t seed = IS_NULL(sfp[1].o) ? 0 : ARG_uinteger(sfp[1]);
	knh_srand(seed);
	KNH_RETURN_void(ctx, sfp);
}

/* ------------------------------------------------------------------------ */

knh_uinteger_t knh_rand()
{
#ifdef KNH_USING_INT32
	return (knh_uinteger_t)genrand_int31();
#else
	return (knh_uinteger_t)genrand64_int63();
#endif
}

/* ------------------------------------------------------------------------ */

knh_float_t knh_float_rand()
{
#ifdef KNH_USING_INT32
	return (knh_float_t)genrand64_real1();
#else
	return (knh_float_t)genrand_real1();
#endif
}

/* ------------------------------------------------------------------------ */

#ifdef __cplusplus
}
#endif

==> konoha-0.2.4-rc1.tar.gz: konoha-0.2.4-rc1/konoha/runtime/konoha_ext.c <==
/****************************************************************************
 * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER
 *
 * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
 *           (c) 2008-      Konoha Software Foundation
 * All rights reserved.
 *
 * You may choose one of the following two licenses when you use konoha.
 * See www.konohaware.org/license.html for further information.
 *
 * (1) GNU General Public License 2.0      (with    KONOHA_UNDER_GPL2)
 * (2) Konoha Software Foundation License 1.0
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

/* ************************************************************************ */

#include"commons.h"
#include<time.h>
#ifdef KNH_USING_POSIX
#include<unistd.h>
#endif

/* ************************************************************************ */

#ifdef __cplusplus
extern "C" {
#endif

/* ------------------------------------------------------------------------ */
/* [random] */

void init_genrand(unsigned long s);
void init_genrand64(unsigned long long seed);
unsigned long genrand_int31(void);
unsigned long long genrand64_int63(void);
double genrand_real1(void);
double genrand64_real1(void);

/* ------------------------------------------------------------------------ */

void knh_srand(knh_uinteger_t seed)
{
	if(seed == 0) {
#ifdef KNH_USING_POSIX
		seed = (knh_uinteger_t)time(NULL) + getpid();
#else
		seed = (knh_uinteger_t)time(NULL);
#endif
	}
#ifdef KNH_USING_INT32
	init_genrand((unsigned long)seed);
#else
	init_genrand64((unsigned long long int)seed);
#endif
}

/* ------------------------------------------------------------------------ */
/* void System.setRandomSeed(Int seed) */

METHOD knh__System_setRandomSeed(Ctx *ctx, knh_sfp_t *sfp)
{
	knh_uinteger_t seed = IS_NULL(sfp[1].o) ? 0 : ARG_uinteger(sfp[1]);
	knh_srand(seed);
	KNH_RETURN_void(ctx, sfp);
}

/* ------------------------------------------------------------------------ */

knh_uinteger_t knh_rand()
{
#ifdef KNH_USING_INT32
	return (knh_uinteger_t)genrand_int31();
#else
	return (knh_uinteger_t)genrand64_int63();
#endif
}

/* ------------------------------------------------------------------------ */

knh_float_t knh_float_rand()
{
#ifdef KNH_USING_INT32
	return (knh_float_t)genrand_real1();
#else
	return (knh_float_t)genrand64_real1();
#endif
}

/* ------------------------------------------------------------------------ */

#ifdef __cplusplus
}
#endif
